@@ -20,6 +20,7 @@ except ImportError:
     Qt = None
     QProgressDialog = None
 
+from .. import __version__
 from ..utils.exceptions import UnrecognizedFormat
 
 
@@ -78,6 +79,13 @@ PRANA_STAGE_KEY = {'0': 'Wake',
                    '3': 'NREM3',
                    '5': 'REM'}
 
+PHYSIP_STAGE_KEY = {'0': 'NREM3',
+                   '1': 'NREM2',
+                   '2': 'NREM1',
+                   '3': 'REM',
+                   '4': 'Wake',
+                   '5': 'Artefact'}
+
 def parse_iso_datetime(date):
     try:
         return datetime.strptime(date, "%Y-%m-%dT%H:%M:%S")
@@ -366,7 +374,23 @@ class Annotations():
             stages = self.rater.find('stages')
 
             if source == 'domino':
-                stage_start = datetime.strptime(lines[7][:8], '%H:%M:%S')
+                
+                for i, line in enumerate(lines):
+                    if line[0].isdigit():
+                        first_line = i
+                        break
+                
+                if lines[first_line].index(';') > 15:
+                    idx_time = (11, 19)
+                    idx_stage = (25, 26)
+                    stage_key = PHYSIP_STAGE_KEY
+                else:
+                    idx_time = (0, 8)
+                    idx_stage = (14, 16)
+                    stage_key = DOMINO_STAGE_KEY
+                
+                stage_start = datetime.strptime(
+                        lines[first_line][idx_time[0]:idx_time[1]], '%H:%M:%S')
                 stage_day = int(lines[1][12:14])
                 stage_month = int(lines[1][15:17])
                 stage_start_for_delta = stage_start.replace(year=1999,
@@ -376,11 +400,6 @@ class Annotations():
                 first_second = int((stage_start_for_delta -
                                     rec_start_for_delta).total_seconds())
 
-                first_line = 7
-
-                stage_key = DOMINO_STAGE_KEY
-                idx_stage = (14, 16)
-
             elif source == 'remlogic':
                 stage_start = datetime.strptime(lines[14][:19],
                                                 '%Y-%m-%dT%H:%M:%S')
@@ -451,7 +470,10 @@ class Annotations():
                 first_line = 5
                 
                 stage_key = PRANA_STAGE_KEY
-                idx_stage = (45, 46)
+                
+                spacer = next(i for i, j in enumerate(lines[5][30:]) \
+                              if j.strip())
+                idx_stage = (30 + spacer, 30 + spacer + 1)
 
             else:
                 raise ValueError('Unknown source program for staging file')
@@ -660,6 +682,20 @@ class Annotations():
                 events.remove(e)
 
         self.save()
+        
+    def rename_event_type(self, name, new_name):
+        """Rename event type."""
+
+        if name not in self.event_types:
+            lg.info('Event type ' + name + ' was not found.')
+
+        events = self.rater.find('events')
+
+        for e in list(events):
+            if e.get('type') == name:
+                e.set('type', new_name)
+
+        self.save()
 
     def add_event(self, name, time, chan=''):
         """Add event to annotations file.
@@ -1085,17 +1121,14 @@ class Annotations():
         """
         if self.rater is None:
             raise IndexError('You need to have at least one rater')
-        lg.info('epoch_start: ' + str(epoch_start))
         cycles = self.rater.find('cycles')
         for one_mrkr in cycles.iterfind('cyc_start'):
-            lg.info('cycle: ' + one_mrkr.text)
             if int(one_mrkr.text) == epoch_start:
                 cycles.remove(one_mrkr)
                 self.save()
                 return
 
         for one_mrkr in cycles.iterfind('cyc_end'):
-            lg.info('cycle: ' + one_mrkr.text)
             if int(one_mrkr.text) == epoch_start:
                 cycles.remove(one_mrkr)
                 self.save()
@@ -1109,10 +1142,8 @@ class Annotations():
             raise IndexError('You need to have at least one rater')
 
         cycles = self.rater.find('cycles')
-        for one_mrkr in cycles.iterfind('cyc_start'):
-            cycles.remove(one_mrkr)
-        for one_mrkr in cycles.iterfind('cyc_end'):
-            cycles.remove(one_mrkr)
+        for cyc in list(cycles):
+            cycles.remove(cyc)
 
         self.save()
 
@@ -1181,6 +1212,7 @@ class Annotations():
         
             with open(file_to_export, 'w', newline='') as f:
                 csv_file = writer(f)
+                csv_file.writerow(['Wonambi v{}'.format(__version__)])
                 csv_file.writerow(('clock start time', 'start', 'end',
                                    'stage'))
     
@@ -1192,7 +1224,12 @@ class Annotations():
                                        epoch['end'],
                                        epoch['stage']))
                     
-        if 'remlogic' == xformat:
+        if 'remlogic' in xformat:
+            
+            columns = 'Time [hh:mm:ss]\tEvent\tDuration[s]\n'
+            if 'remlogic_fr' == xformat:
+                columns = 'Heure [hh:mm:ss]\tEvénement\tDurée[s]\n'
+                
             patient_id = splitext(basename(self.dataset))[0]
             rec_date = self.start_time.strftime('%d/%m/%Y')
             stkey = {v:k for k, v in REMLOGIC_STAGE_KEY.items()}
@@ -1203,7 +1240,7 @@ class Annotations():
             with open(file_to_export, 'w') as f:
                 f.write('RemLogic Event Export\n')
                 f.write('Patient:\t' + patient_id + '\n')
-                f.write('Parient ID:\t' + patient_id + '\n')
+                f.write('Patient ID:\t' + patient_id + '\n')
                 f.write('Recording Date:\t' + rec_date + '\n')
                 f.write('\n')
                 f.write('Events Included:\n')
@@ -1212,7 +1249,7 @@ class Annotations():
                     f.write(i + '\n')
                 
                 f.write('\n')
-                f.write('Time [hh:mm:ss]\tEvent\tDuration[s]\n')
+                f.write(columns)
                 
                 for epoch in self.epochs:
                     epoch_time = (self.start_time +
@@ -1282,7 +1319,8 @@ class Annotations():
         with open(filename, 'w', newline='') as f:
             lg.info('Writing to' + str(filename))
             csv_file = writer(f)
-            csv_file.writerow(['Total dark time',
+            csv_file.writerow(['Wonambi v{}'.format(__version__)])
+            csv_file.writerow(['Total dark time (Time in bed)',
                                'Sleep onset latency',
                                'Sleep period time',
                                'WASO',
@@ -1352,8 +1390,9 @@ class Annotations():
             return
         
         with open(filename, 'w', newline='') as f:
-            lg.info('Writing to' + str(filename))
+            lg.info('Writing to ' + str(filename))
             csv_file = writer(f)
+            csv_file.writerow(['Wonambi v{}'.format(__version__)])
             csv_file.writerow(headings_row)
             
             for i, ev in enumerate(events):
