@@ -7,6 +7,7 @@ Data.__call__, which needs to be very general.
 from collections import OrderedDict, Iterable
 from copy import deepcopy
 from logging import getLogger
+from pathlib import Path
 
 from numpy import arange, array, empty, ix_, NaN, squeeze, where
 
@@ -373,7 +374,12 @@ class Data:
             "name" : str (name of the marker),
             "start" : float (start time in seconds)
             "end" : float (end time in seconds)
+
+        'bids' has an optional argument "markers", like in 'brainvision'
         """
+        filename = Path(filename)
+        filename.parent.mkdir(parents=True, exist_ok=True)
+
         export_format = export_format.lower()
         if export_format == 'edf':
             from .ioeeg import write_edf  # avoid circular import
@@ -396,6 +402,10 @@ class Data:
             from .ioeeg import write_brainvision
             write_brainvision(self, filename, **options)
 
+        elif export_format == 'bids':
+            from .ioeeg import write_bids
+            write_bids(self, filename, **options)
+
         else:
             raise ValueError('Cannot export to ' + export_format)
 
