@@ -16,4 +16,4 @@ from .wonambi import Wonambi, write_wonambi
 from .micromed import Micromed
 from .bci2000 import BCI2000
 from .text import Text
-from .bids import BIDS, write_bids
+from .bids import BIDS, write_bids, write_bids_channels
