@@ -91,7 +91,8 @@ def frequency(data, output='spectraldensity', scaling='power', sides='one',
     recompute the sampling frequency based on the time axis.
     """
     if output not in ('spectraldensity', 'complex', 'csd'):
-        raise TypeError(f'output can be "spectraldensity" or "complex", not "{output}"')
+        raise TypeError(f'output can be "spectraldensity", "complex" or "csd",'
+                        ' not "{output}"')
     if 'time' not in data.list_of_axes:
         raise TypeError('\'time\' is not in the axis ' +
                         str(data.list_of_axes))
@@ -323,7 +324,7 @@ def timefrequency(data, method='morlet', time_skip=1, **options):
     return timefreq
 
 
-def band_power(data, freq, scaling='power', array_out=False):
+def band_power(data, freq, scaling='power', n_fft=None, array_out=False):
     """Compute power or energy acoss a frequency band, and its peak frequency.
     Power is estimated using the mid-point rectangle rule. Input can be 
     ChanTime or ChanFreq.
@@ -340,6 +341,9 @@ def band_power(data, freq, scaling='power', array_out=False):
         'time' or 'spectrum'
     scaling : str
         'power' or 'energy', only used if data is ChanTime
+    n_fft : int
+        length of FFT. if shorter than input signal, signal is truncated; if 
+        longer, signal is zero-padded to length
     array_out : bool
         if True, will return two arrays instead of two dict.
 
@@ -354,8 +358,8 @@ def band_power(data, freq, scaling='power', array_out=False):
         power = {}
         peakf = {}
     else:
-        power = zeros((data.axis['chan'].number_of(), 1))
-        peakf = zeros((data.axis['chan'].number_of(), 1))
+        power = zeros((data.number_of('chan')[0], 1))
+        peakf = zeros((data.number_of('chan')[0], 1))
 
     if 'power' == scaling:
         detrend = 'linear'
@@ -367,7 +371,7 @@ def band_power(data, freq, scaling='power', array_out=False):
     if isinstance(data, ChanFreq):
         Sxx = data
     elif isinstance(data, ChanTime):
-        Sxx = frequency(data, scaling=scaling, detrend=detrend)
+        Sxx = frequency(data, scaling=scaling, n_fft=n_fft, detrend=detrend)
     else:
         raise ValueError('Invalid data type')
     
