@@ -312,6 +312,10 @@ class Notes(QTabWidget):
         act = QAction(QIcon(ICON['del_eventtype']), 'Delete Event Type', self)
         act.triggered.connect(self.delete_eventtype)
         actions['del_eventtype'] = act
+        
+        act = QAction('Rename event type', self)
+        act.triggered.connect(self.rename_eventtype)
+        actions['rename_eventtype'] = act
 
         act = QAction('New name', self)
         act.triggered.connect(self.markers_to_events)
@@ -323,7 +327,6 @@ class Notes(QTabWidget):
         
         act = QAction('Merge Events...', self)
         act.triggered.connect(self.parent.show_merge_dialog)
-        act.setEnabled(False)
         actions['merge_events'] = act
 
         act = QAction(QIcon(ICON['event']), 'Event Mode', self)
@@ -444,6 +447,10 @@ class Notes(QTabWidget):
         act = QAction('RemLogic', self)
         act.triggered.connect(partial(self.export, xformat='remlogic'))
         actions['export_to_remlogic'] = act
+        
+        act = QAction('RemLogic FR', self)
+        act.triggered.connect(partial(self.export, xformat='remlogic_fr'))
+        actions['export_to_remlogic_fr'] = act
 
         act = QAction('Export events...', self)
         act.triggered.connect(self.parent.show_export_events_dialog)
@@ -538,12 +545,10 @@ class Notes(QTabWidget):
         annotations and channels are active.
         """
         if self.annot is not None and self.parent.channels.groups:
-            self.action['merge_events'].setEnabled(True)
             self.action['spindle'].setEnabled(True)
             self.action['slow_wave'].setEnabled(True)
             self.action['analyze'].setEnabled(True)
         else:
-            self.action['merge_events'].setEnabled(False)
             self.action['spindle'].setEnabled(False)
             self.action['slow_wave'].setEnabled(False)
             self.action['analyze'].setEnabled(False)
@@ -1325,7 +1330,25 @@ class Notes(QTabWidget):
         if answer[1]:
             self.annot.remove_event_type(answer[0])
             self.display_eventtype()
+            self.update_annotations()
 
+    def rename_eventtype(self, test_name=None, test_new_name=None):
+        """action: create dialog to rename event type."""
+        if test_name and test_new_name:
+            name = test_name, True
+            new_name = test_new_name, True
+        else:
+            name = QInputDialog.getText(self, 'Rename Event Type',
+                                        'Enter name of event type to rename.')
+        
+        if name[1]:
+            new_name = QInputDialog.getText(self, 'Rename Event Type',
+                                            'Enter new name for event type.')
+            
+            if new_name[1]:
+                self.annot.rename_event_type(name[0], new_name[0])
+                self.display_eventtype()
+    
     def add_event(self, name, time, chan):
         """Action: add a single event."""
         self.annot.add_event(name, time, chan=chan)
@@ -1426,7 +1449,6 @@ class Notes(QTabWidget):
             detector.min_interval = params['interval']
 
         elif method in SLOW_WAVE_METHODS:
-            lg.info('building SW detector with ' + method)
             detector = DetectSlowWave(method=method, duration=duration)
 
             detector.det_filt['freq'] = freq
@@ -1468,10 +1490,16 @@ class Notes(QTabWidget):
             self.parent.statusBar().showMessage('No score file loaded')
             return
 
-        filename = splitext(self.annot.xml_file)[0] + '.csv'
-        filename, _ = QFileDialog.getSaveFileName(self, 'Export stages',
-                                                  filename,
-                                                  'Sleep stages (*.csv)')
+        if xformat == 'csv':
+            filename = splitext(self.annot.xml_file)[0] + '.csv'
+            filename, _ = QFileDialog.getSaveFileName(self, 'Export stages',
+                                                      filename,
+                                                      'Sleep stages (*.csv)')
+        if 'remlogic' in xformat:
+            filename = splitext(self.annot.xml_file)[0] + '.txt'
+            filename, _ = QFileDialog.getSaveFileName(self, 'Export stages',
+                                                      filename,
+                                                      'Sleep stages (*.txt)')
         if filename == '':
             return
 
@@ -1681,18 +1709,18 @@ class MergeDialog(QDialog):
                                      merge_to_longer=merge_to_longer)
 
             else:
-                channels = set([x['chan'] for x in events])
+                channels = sorted(set([y for x in events for y in x['chan']]))
                 events = []
                 chan_events = []
 
                 for chan in channels:
+                    chan_events = []
 
                     for etype in evt_types:
 
                         chan_events.extend(self.parent.notes.annot.get_events(
                                 name=etype, chan=chan, qual='Good'))
-
-                    events.extend(merge_close(chan_events, min_interval,
+                        events.extend(merge_close(chan_events, min_interval,
                                               merge_to_longer=merge_to_longer))
 
             for etype in evt_types:
